summaryrefslogtreecommitdiff
path: root/gst/faceoverlay
diff options
context:
space:
mode:
authorWim Taymans <wim.taymans@collabora.co.uk>2012-09-14 16:45:34 +0200
committerWim Taymans <wim.taymans@collabora.co.uk>2012-09-14 16:45:34 +0200
commitb8f913555d75504c0b19bed76d936685182d1b03 (patch)
treeea81b29f674032601b606e6c36c46a091b99b4a4 /gst/faceoverlay
parent0d8f8a5134c16e6bb4754a2d712a5bcad401e44d (diff)
ffmpegcolorspace is no more
Diffstat (limited to 'gst/faceoverlay')
-rw-r--r--gst/faceoverlay/gstfaceoverlay.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gst/faceoverlay/gstfaceoverlay.c b/gst/faceoverlay/gstfaceoverlay.c
index ce59b42fb..6ca7e404f 100644
--- a/gst/faceoverlay/gstfaceoverlay.c
+++ b/gst/faceoverlay/gstfaceoverlay.c
@@ -50,7 +50,7 @@
* <refsect2>
* <title>Example launch line</title>
* |[
* gst-launch autovideosrc ! ffmpegcolorspace ! faceoverlay location=/path/to/gnome-video-effects/pixmaps/bow.svg x=-5 y=-15 w=0.3 h=0.1 ! ffmpegcolorspace ! autovideosink
* ]|
* </refsect2>
*/
@@ -108,7 +108,7 @@ gst_face_overlay_create_children (GstFaceOverlay * filter)
GstElement *csp, *face_detect, *overlay;
GstPad *pad;
- csp = gst_element_factory_make ("ffmpegcolorspace", NULL);
+ csp = gst_element_factory_make ("videoconvert", NULL);
face_detect = gst_element_factory_make ("facedetect", NULL);
overlay = gst_element_factory_make ("rsvgoverlay", NULL);
@@ -141,7 +141,7 @@ missing_element:
{
/* clean up */
if (csp == NULL)
- GST_ERROR_OBJECT (filter, "ffmpegcolorspace element not found");
+ GST_ERROR_OBJECT (filter, "videoconvert element not found");
else
gst_object_unref (csp);
@@ -50,7 +50,7 @@
* <title>Example launch line</title>
* |[
- * gst-launch autovideosrc ! ffmpegcolorspace ! faceoverlay location=/path/to/gnome-video-effects/pixmaps/bow.svg x=-5 y=-15 w=0.3 h=0.1 ! ffmpegcolorspace ! autovideosink
+ * gst-launch autovideosrc ! videoconvert ! faceoverlay location=/path/to/gnome-video-effects/pixmaps/bow.svg x=-5 y=-15 w=0.3 h=0.1 ! videoconvert ! autovideosink
* ]|
* </refsect2>